require_relative '../spec_helper'
require_relative '../../lib/scabox_sdk'

RSpec.describe 'Codebase' do
  describe 'parse_opts' do
    context 'should parse all the provided options' do
      let(:scanner) { ScaBox::CodebaseScanner.new(name: 'test', description: 'test', support: []) }
      subject { scanner.parse_opts(['-c', 'codebase', '-f', 'json', '-o', 'outputfile', '-v']) }

      it 'codebase - is expected to eq "codebase"' do
        expect(subject.codebase).to eq 'codebase'
      end

      it "format - is expected to eq :json" do
        expect(subject.format).to eq :json
      end

      it "output - is expected to eq outputfile" do
        expect(subject.output).to eq 'outputfile'
      end

      it "verbose - is expected to equal true" do
        expect(subject.verbose).to be true
      end

      it "info - is expected to eq false" do
        expect(subject.info).to be false
      end

      it "color - is expected to equal true" do
        expect(subject.color).to be true
      end
    end
  end

  describe 'run' do
    context 'should fail when codebase is not provided' do
      let(:scanner) { ScaBox::CodebaseScanner.new(name: 'test', description: 'test', support: []) }
      before do
        scanner.parse_opts([])
      end

      it do
        expect { scanner.run }.to raise_error(SystemExit) do |error|
          expect( error.status ).to eq(1)
        end
      end
      it do
        expect { scanner.run }.to raise_error(SystemExit) do |error|
          expect( error.message ).to eq('exit')
        end
      end
    end

    context 'should raise name error for prepare_command method when correct options are provided' do
      let(:scanner) { ScaBox::CodebaseScanner.new(name: 'test', description: 'test', support: []) }
      let(:report) { '/tmp/codebasescanner_output.json' }

      before do
        File.delete(report) if File.exist?(report)

        $VERBOSE = nil
        ARGV = ['-c', 'codebase', '-f', 'json', '-o', report, '-v']
      end

      it "should raise name error for prepare_command method when correct options are provided" do
        expect { scanner.run }.to raise_error(NameError) do |error| # #<NameError: undefined local variable or method `prepare_command' for #<ScaBox::CodebaseScanner:0x00005616ee3fab00>>
          expect( error.message ).to match(/undefined.*prepare_command/)
        end
      end
    end
  end

end
