require_relative '../spec_helper'
require_relative '../../lib/scabox_sdk'

RSpec.describe 'Container' do
  describe 'parse_opts' do
    context 'should parse all the provided options' do
      let(:scanner) { ScaBox::ContainerScanner.new(name: 'test', description: 'test', support: []) }
      subject { scanner.parse_opts(['-n', 'imagename', '-p', 'imagefile', '-f', 'json', '-o', 'outputfile', '-v']) }

      it "image_name - is expected to equal imagename" do
        expect(subject.image_name).to eq 'imagename'
      end

      it "image_file - is expected to equal imagefile" do
        expect(subject.image_file).to eq 'imagefile'
      end

      it "format - is expected to eq :json" do
        expect(subject.format).to eq :json
      end

      it "output - is expected to eq outputfile" do
        expect(subject.output).to eq 'outputfile'
      end

      it "verbose - is expected to equal true" do
        expect(subject.verbose).to be true
      end

      it "info - is expected to eq false" do
        expect(subject.info).to be false
      end

      it "color - is expected to equal true" do
        expect(subject.color).to be true
      end
    end
  end

  describe 'run' do
    context 'should fail when image name and image file are not provided' do
      let(:scanner) { ScaBox::ContainerScanner.new(name: 'test', description: 'test', support: []) }

      before do
        scanner.parse_opts([])
      end

      it do
        expect { scanner.run }.to raise_error(SystemExit) do |error|
          expect( error.status ).to eq(1)
        end
      end
      it do
        expect { scanner.run }.to raise_error(SystemExit) do |error|
          expect( error.message ).to eq('exit')
        end
      end
    end

    context 'should raise name error for prepare_command method when correct options are provided' do
      let(:scanner) { ScaBox::ContainerScanner.new(name: 'test', description: 'test', support: []) }
      let(:report) { '/tmp/containerscanner_output.json' }

      before do
        File.delete(report) if File.exist?(report)

        $VERBOSE = nil
        ARGV = ['-n', 'python:3.4-alpine', '-f', 'json', '-o', report, '-v']
      end

      it "should raise name error for prepare_command method when correct options are provided" do
        expect { scanner.run }.to raise_error(NameError) do |error| # #<NameError: undefined local variable or method `prepare_command' for #<ScaBox::ContainerScanner:0x00005616ee3fab00>>
          expect( error.message ).to match(/undefined.*prepare_command/)
        end
      end
    end
  end

end
