require_relative '../spec_helper'
require_relative '../../lib/scabox_sdk'

RSpec.describe 'Printer' do
  let(:runner) { ScaBox::CodebaseScanner.new(name: 'test', description: 'test', support: []) }

  before do
    runner.parse_opts(['--no-color'])
  end

  describe 'print_title' do
    context 'should print with title format' do
      it {expect { runner.print_title('abc') }.to output("[*] abc\n").to_stdout }
    end
  end

  describe 'print_normal' do
    context 'should print with normal format' do
      it {expect { runner.print_normal('abc') }.to output("abc\n").to_stdout }
    end
  end

  describe 'print_success' do
    context 'should print with success format' do
      it {expect { runner.print_success('abc') }.to output("[SUCCESS] abc\n").to_stdout }
    end
  end

  describe 'print_error' do
    context 'should print with error format' do
      it {expect { runner.print_error('abc') }.to output("[ ERROR ] abc\n").to_stdout }
    end
  end

  describe 'print_with_label' do
    context 'should print with label format' do
      it {expect { runner.print_with_label('abc', 'def') }.to output("[def] abc\n").to_stdout }
    end
  end

  describe 'print_debug' do
    context 'should print with debug format' do
      it {expect { runner.print_debug('abc') }.to output(/DEBUG\|.*\| abc/).to_stdout }
    end
  end
end
